changeset 3661:4ecbbf74e532

Modified aspect reference, uses default PAL values... Difference to NTSC should be minimal enough so that no checking of videomode is necessary.
author mswitch
date Sat, 22 Dec 2001 16:20:32 +0000
parents a515ff1954fd
children 1e0052d8c532
files libvo/vo_dxr3.c
diffstat 1 files changed, 1 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/libvo/vo_dxr3.c	Sat Dec 22 16:19:00 2001 +0000
+++ b/libvo/vo_dxr3.c	Sat Dec 22 16:20:32 2001 +0000
@@ -123,7 +123,7 @@
     /* Calculate screen res */    
     aspect_save_orig(v_width,v_height);
     aspect_save_prescale(scr_width,scr_height);
-    aspect_save_screenres(720,576); /* Reference values from DVD spec */
+    aspect_save_screenres(702,575); /* Reference values from DVD spec (711,483) (702,575) */
     aspect(&s_width,&s_height,A_NOZOOM);
     s_width = (scr_width+15)/16; s_width*=16;
     s_height = (scr_height+15)/16; s_height*=16;